Installation
============

Requirements
------------
* Python 2.7, 3.4, 3.5, or PyPy

Optional dependencies
---------------------
* `lxml` library inside system if you consider using it as a parser


Installing
----------
.. code-block:: bash

    pip install verata
